/// <reference types="node" />
import * as web3 from '@solana/web3.js';
import * as beet from '@metaplex-foundation/beet';
import * as definedTypes from '../types';
export declare type CandyMachineArgs = {
    authority: web3.PublicKey;
    wallet: web3.PublicKey;
    tokenMint: beet.COption<web3.PublicKey>;
    itemsRedeemed: beet.bignum;
    data: definedTypes.CandyMachineData;
};
export declare class CandyMachine implements CandyMachineArgs {
    readonly authority: web3.PublicKey;
    readonly wallet: web3.PublicKey;
    readonly tokenMint: beet.COption<web3.PublicKey>;
    readonly itemsRedeemed: beet.bignum;
    readonly data: definedTypes.CandyMachineData;
    private constructor();
    static fromArgs(args: CandyMachineArgs): definedTypes.CandyMachine;
    static fromAccountInfo(accountInfo: web3.AccountInfo<Buffer>, offset?: number): [CandyMachine, number];
    static deserialize(buf: Buffer, offset?: number): [CandyMachine, number];
    serialize(): [Buffer, number];
    static byteSize(args: CandyMachineArgs): number;
    static getMinimumBalanceForRentExemption(args: CandyMachineArgs, connection: web3.Connection, commitment?: web3.Commitment): Promise<number>;
    pretty(): {
        authority: string;
        wallet: string;
        tokenMint: web3.PublicKey;
        itemsRedeemed: beet.bignum;
        data: definedTypes.CandyMachineData;
    };
}
export declare const candyMachineBeet: beet.FixableBeetStruct<definedTypes.CandyMachine, definedTypes.CandyMachineArgs & {
    accountDiscriminator: number[];
}>;
